package examples.intro;

import java.sql.*;
import java.util.Properties;
import weblogic.common.*;

/**
 * booksT3Pool example. Companion to "Getting Started with
 * BEA WebLogic Server 4.5".
 *
 * @author Copyright (c) 2000, BEA Systems, Inc. All Rights Reserved.
 */
public class booksT3pool {

  public static void main(String argv[]) throws Exception {

    T3Client t3 = null;
    Connection conn = null;
    Properties t3props = new Properties();


    try {
      t3 = new T3Client("t3://localhost:7001");
      t3.connect();
      t3props.put("weblogic.t3", t3);
      t3props.put("weblogic.t3.connectionPoolID", "demoPool");
      Class.forName("weblogic.jdbc.t3.Driver").newInstance();
      conn = DriverManager.getConnection("jdbc:weblogic:t3", 
                                         t3props);

      Statement s = conn.createStatement();

      try {
        // First, drop the "books" table, in case it 
        // already exists. If it does not, then this 
        // statement will get an warning that can be ignored.
        System.out.println("Dropping table books.");
        s.execute("drop table books");
      }
      catch ( SQLException se ) {;}
      

      // Now, create the "books" table and insert some data.
      System.out.println("Creating table books.");
      s.execute("create table books (title varchar(40), " +
                "author varchar(40), publisher varchar(40),"+
                "isbn varchar(20))");

      // Use a PreparedStatement to insert rows in the table.
      System.out.println("Loading table.");
      PreparedStatement ps = conn.prepareStatement(
                 "insert into books " +
                 "(title,author,publisher,isbn) " +
                 " values (?, ?, ?, ?)");

      ps.setString(1, "Java in a Nutshell");
      ps.setString(2, "David Flanagan");
      ps.setString(3, "O'Reilly");
      ps.setString(4, "1-56592-262-X");
      ps.execute();

      ps.setString(1, "Java Examples in a Nutshell");
      //      ps.setString(2, "David Flanagan");
      //      ps.setString(3, "O'Reilly");
      ps.setString(4, "1-56592-371-5");
      ps.execute();
      
      ps.setString(1, "Design Patterns");
      ps.setString(2, "Gamma, Helm, Johnson, Vlissides");
      ps.setString(3, "Addison-Wesley");
      ps.setString(4, "0-201-63361-2");
      ps.execute();
      
      System.out.println("Retrieving rows.");
      s.execute("select * from books");

      ResultSet rs = s.getResultSet();
      while (rs.next()) {
        System.out.println(rs.getString("title") + "\n\t" + 
                           rs.getString("author") + "\n\t" +
                           rs.getString("publisher") + "\n\t" +
                           rs.getString("isbn"));
      }
      rs.close();
      s.close();
      ps.close();
    } finally {
      try {conn.close();}    catch (Exception e) {;}
      try {t3.disconnect();} catch (Exception e) {;}
    }
  }
}



