package examples.intro;

import java.sql.*;
import java.util.Properties;
import weblogic.common.*;



/**
 * booksT3 example. Companion to "Getting Started with
 * BEA WebLogic Server 4.5".
 *
 * @author Copyright (c) 2000, BEA Systems, Inc. All Rights Reserved.
 */
public class booksT3 {

  public static void main(String argv[]) throws Exception {

    T3Client   t3   = null;
    Connection conn = null;

    try {
      t3 = new T3Client("t3://localhost:7001");
      t3.connect();


      // For Cloudscape databases, none of these
      // properties are actually required, but they 
      // are left here for demonstration purposes.
      Properties dbprops = new Properties();
      dbprops.put("user",     "");
      dbprops.put("password", "");
      dbprops.put("server",   "demo");

      // These properties are used to get the WebLogic JDBC
      // connection. The first, "weblogic.t3.dbprobs", holds the 
      // properties constructed for the back-end JDBC connection. 
      Properties t3props = new Properties();
      t3props.put("weblogic.t3.dbprops",         dbprops);
      t3props.put("weblogic.t3",                 t3);
      t3props.put("weblogic.t3.driverClassName",
		  "COM.cloudscape.core.JDBCDriver");
      t3props.put("weblogic.t3.driverURL",
		  "jdbc:cloudscape:demo");

      // This loads the JDBC driver into the JVM. It has to be
      // loaded this way because DriverManager does not actually
      // load drivers. It just searches for a loaded driver that
      // can service the database URL. 
      Class.forName("weblogic.jdbc.t3.Driver").newInstance();
      conn = DriverManager.getConnection("jdbc:weblogic:t3", t3props);

      Statement s = conn.createStatement();

      try {
	// First, drop the "books" table, in case it already exists. If
	// it does not, then this statement will get an error that can
	// be ignored.
	
	System.out.println("Dropping table books.");
	s.execute("drop table books");
      }
      catch ( SQLException se ) {;}
      
      // Now, create the "books" table and insert some data.
      System.out.println("Creating table books.");
      s.execute("create table books (title varchar(40), author varchar(40)," +
		"publisher varchar(40), isbn varchar(20))");
      System.out.println("Loading table.");
      // To embed an apostrophe in a string in Cloudscape, you double it ('').
      // In a Java statement that means escaping both with a backslash.
      s.execute("insert into books (title, author, publisher, isbn) " +
		" values ('Java in a Nutshell', 'David Flanagan'," +
		" 'O\'\'Reilly', '1-56592-262-X')");
      s.execute("insert into books (title, author, publisher, isbn) " +
		" values ('Java Examples in a Nutshell', 'David Flanagan'," +
		" 'O\'\'Reilly', '1-56592-371-5')");
      s.execute("insert into books (title, author, publisher, isbn) " +
		" values ('Design Patterns', 'Gamma, Helm, Johnson, Vlissides'," +
		" 'Addison-Wesley', '0-201-63361-2')");
      
      System.out.println("Retrieving rows.");
      s.execute("select * from books");

      ResultSet rs = s.getResultSet();
      while (rs.next()) {
	System.out.println(rs.getString("title") + "\n\t" + 
			   rs.getString("author") + "\n\t" +
			   rs.getString("publisher") + "\n\t" +
			   rs.getString("isbn"));
      }
      rs.close();
      s.close();

    } finally {
      try {conn.close();}    catch (Exception e) {;}
      try {t3.disconnect();} catch (Exception e) {;}
    }
  }
}
